@@ -212,7 +212,11 @@ find_jars() {
     looked_for_jars=1
     for jar in $@ ; do
 	if locate_jar $jar; then
-	    JAVA_CLASSPATH=$JAVA_CLASSPATH:$found_jar
+            if [ -z "$JAVA_CLASSPATH" ]; then
+	        JAVA_CLASSPATH=$found_jar
+            else
+	        JAVA_CLASSPATH=$JAVA_CLASSPATH:$found_jar
+            fi
 	else
 	    java_warning "Unable to locate $jar in $JAVA_JARPATH"
 	fi
