@@ -22,6 +22,8 @@
 # They can also be used for the JAVA_FLAVOR environment variable, see
 # java-wrappers(7).
 
+__arch=$(dpkg --print-architecture)
+
 # default runtime
 __jvm_default="/usr/lib/jvm/default-java"
 
@@ -36,15 +38,18 @@ __jvm_sunmin5="$__jvm_sun6"
 # Now, free runtimes:
 __jvm_gcj2="/usr/lib/jvm/java-*-gcj-4.* "
 __jvm_gcj5="/usr/lib/jvm/java-1.5*-gcj-4.* "
-__jvm_openjdk6="/usr/lib/jvm/java-6-openjdk"
+__jvm_openjdk6="/usr/lib/jvm/java-6-openjdk-$__arch /usr/lib/jvm/java-6-openjdk"
+__jvm_openjdk7="/usr/lib/jvm/java-7-openjdk-$__arch /usr/lib/jvm/java-7-openjdk"
+
 
 # And a few aliases
 __jvm_gcj="$__jvm_gcj2"
-__jvm_openjdk="$__jvm_openjdk6"
+__jvm_openjdk="$__jvm_openjdk7 $__jvm_openjdk6"
 
 # The java* runtimes:
+__jvm_java7="$__jvm_openjdk7"
 # -> corresponds to Provides: java6-runtime 
-__jvm_java6="$__jvm_openjdk6 $__jvm_sun6"
+__jvm_java6="$__jvm_openjdk6 $__jvm_sun6 $__jvm_java7"
 # -> corresponds to Provides: java5-runtime 
 __jvm_java5="$__jvm_gcj5 $__jvm_java6"
 # -> corresponds to Provides: java2-runtime 
